@@ -12,7 +12,7 @@
 #include <QDataStream>
 
 SvgBrowserExtension::SvgBrowserExtension(SvgPart *part)
-    : KParts::BrowserExtension(part)
+    : KParts::NavigationExtension(part)
     , m_part(part)
 {
 }
@@ -30,7 +30,7 @@ int SvgBrowserExtension::yOffset()
 void SvgBrowserExtension::saveState(QDataStream &stream)
 {
     stream << m_part->zoom();
-    KParts::BrowserExtension::saveState(stream);
+    KParts::NavigationExtension::saveState(stream);
 }
 
 void SvgBrowserExtension::restoreState(QDataStream &stream)
@@ -39,7 +39,7 @@ void SvgBrowserExtension::restoreState(QDataStream &stream)
     stream >> zoom;
 
     m_part->setExtendedRestoreArguments(zoom);
-    KParts::BrowserExtension::restoreState(stream);
+    KParts::NavigationExtension::restoreState(stream);
 }
 
 #include "moc_svgbrowserextension.cpp"
